<?php
/**
 * @file
 * Main view template.
 *
 * Variables available:
 * - $classes_array: An array of classes determined in
 *   template_preprocess_views_view(). Default classes are:
 *     .view
 *     .view-[css_name]
 *     .view-id-[view_name]
 *     .view-display-id-[display_name]
 *     .view-dom-id-[dom_id]
 * - $classes: A string version of $classes_array for use in the class attribute
 * - $css_name: A css-safe version of the view name.
 * - $css_class: The user-specified classes names, if any
 * - $header: The view header
 * - $footer: The view footer
 * - $rows: The results of the view query, if any
 * - $empty: The empty text to display if the view is empty
 * - $pager: The pager next/prev links to display, if any
 * - $exposed: Exposed widget form/info to display
 * - $feed_icon: Feed icon to display, if any
 * - $more: A link to view more, if any
 *
 * @ingroup views_templates
 */
?>
<div class="<?php print $classes; ?>">
  <?php print render($title_prefix); ?>
  <?php if ($title): ?>
    <?php print $title; ?>
  <?php endif; ?>
  <?php print render($title_suffix); ?>
  <?php global $base_url; ?>
  <div class="view-header">
      <picture>
          <source srcset="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/front/bigdata-hpc-small.png" media="(max-width: 600px)">
  <img src="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/front/bigdata-hpc.png" alt="Big Data" />
          </source>
      </picture>
    <?php print $header; ?>
  </div>
  <?php if ($exposed): ?>
    <div class="view-filters">
      <?php print $exposed; ?>
    </div>
  <?php endif; ?>

  <?php if ($attachment_before): ?>
    <div class="attachment attachment-before">
      <?php print $attachment_before; ?>
    </div>
  <?php endif; ?>

  <?php if ($rows): ?>
    <div class="view-content">
      <?php print $rows; ?>
    </div>
  <?php elseif ($empty): ?>
    <div class="view-empty">
      <?php print $empty; ?>
    </div>
  <?php endif; ?>

  <?php if ($pager): ?>
    <?php print $pager; ?>
  <?php endif; ?>

  <?php if ($attachment_after): ?>
    <div class="attachment attachment-after">
      <?php print $attachment_after; ?>
    </div>
  <?php endif; ?>

  <?php if ($more): ?>
    <?php print $more; ?>
  <?php endif; ?>

  <?php if ($footer): ?>
    <div class="view-footer">
      <?php print $footer; ?>
    </div>
  <?php endif; ?>

  <h2>Software Development</h2>

  <h3>Autosubmit</h3> 
  <p>a versatile tool to manage weather and climate experiments in diverse supercomputing environments. It is a python-based tool to create, manage and monitor experiments using Computing Clusters, HPC’s and Supercomputers remotely via ssh (<a href="https://pypi.python.org/pypi/autosubmit">https://pypi.python.org/pypi/autosubmit</a>).

  <h3>S2dv</h3>
  <p>a set of tools to assess the performance of a model through the computation of typical prediction scores against one or more observational datasets or reanalyses; a reanalysis being a physical extrapolation of observations that relies on the equations from a model, not a pure observational dataset (<a href="https://cran.r-project.org/web/packages/s2dverification/index.html">https://cran.r-project.org/web/packages/s2dverification/index.html</a>).

  <h3>MapGenerator</h3>
  <p>a python toolbox to process and visualise datasets.

  <h3>Ocean and Atmospheric diagnostics</h3>
  <p>a set of functions used to compute derived variables from model output and to format ocean and atmospheric spatial and temporal means into standards usable by other tools.

  <h3>CALIOPE mobile applications for Spain and Europe</h3>
  <p>application that allows the visualisation of air quality forecasts and the concentration maps for the next 12h (Spain) and 48h (Europe) of the main atmospheric contaminants: ozone, nitrogen dioxide, sulfur dioxide, and particulate matter of 10 and 2.5 μm (PM10 and PM2.5). The European app. has been financed by the European Commission within the framework of the project MYGEOSS.

      <picture>
          <source srcset="<?php print $base_url; ?>/sites/default/files/imce/contaminacion-app-caliope.jpeg" media="(max-width: 600px)">
  <img src="<?php print $base_url; ?>/sites/default/files/imce/contaminacion-app-caliope.jpeg" alt="Contaminación de la app caliope" />
          </source>
      </picture>


      <h2>Partners and collaborators</h2>
      <picture>
          <source srcset="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/partners.png" media="(max-width: 600px)">
          <img src="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/partners.png" alt="Partners and collaborators" />
          </source>
      </picture>

      <h2>Projects</h2>
      <picture>
          <source srcset="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/projects.png" media="(max-width: 600px)">
          <img src="<?php print $base_url; ?>/sites/all/themes/ess_theme/images/projects.png" alt="Projects" />
          </source>
      </picture>




  <?php if ($feed_icon): ?>
    <div class="feed-icon">
      <?php print $feed_icon; ?>
    </div>
  <?php endif; ?>

</div><?php /* class view */ ?>
